---
title: software
keywords: documentation
layout: documentation
sidebar: mq_install_sidebar
toc: false
---
## Overview

This class install's specified version of the the MQ software on the system. The source zip file from IBM is found at the location specified at `source_location`. By default it will install only the minimal required set. By using the `install_...` parameters, you can install optional components.

Here is an example on how to use it:

``` puppet
class { '::mq_install::software':
  source_location  => '/software',
  version          => '9.0.0.0'
  tmp_dir          => '/tmp'
  install_ams      => true,
  install_ft       => false,
  install_client   => false,
  install_explorer => true,
  install_xrserver => false,
  install_samples  => false,
  install_sdk      => false,
  install_man      => false,
  install_gskit    => false,
  install_amqp     => false,
  logoutput        => 'true,
}
```

On systems with a secured `/tmp` direcory, you MUST specify the `tmp_dir` parameter and specify a directory that puppet is allowed to execute scripts from. It must also have enough space to receive the extracted MQ installation kit.





## Attributes



Attribute Name                                 | Short Description                                                                                    |
---------------------------------------------- | ---------------------------------------------------------------------------------------------------- |
[install_amqp](#software_install_amqp)         | Specify a value of `true` when you want to install this component.                                   |
[install_ams](#software_install_ams)           | Specify a value of `true` when you want to install this component.                                   |
[install_client](#software_install_client)     | Specify a value of `true` when you want to install this component.                                   |
[install_explorer](#software_install_explorer) | Specify a value of `true` when you want to install this component.                                   |
[install_ft](#software_install_ft)             | Specify a value of `true` when you want to install this component.                                   |
[install_gskit](#software_install_gskit)       | Specify a value of `true` when you want to install this component.                                   |
[install_man](#software_install_man)           | Specify a value of `true` when you want to install this component.                                   |
[install_samples](#software_install_samples)   | Specify a value of `true` when you want to install this component.                                   |
[install_sdk](#software_install_sdk)           | Specify a value of `true` when you want to install this component.                                   |
[install_xrserver](#software_install_xrserver) | Specify a value of `true` when you want to install this component.                                   |
[logoutput](#software_logoutput)               | If you want to see the output of the `exec` resources in the type, you can set this value to `true`. |
[source_location](#software_source_location)   | The location of the MQ software.                                                                     |
[tmp_dir](#software_tmp_dir)                   | This defined type uses a temporary directory.                                                        |
[version](#software_version)                   | The version to be installed.                                                                         |




### source_location<a name='software_source_location'>

The location of the MQ software.

Here is an example on how to use this:

    class { '::mq_install::software':
      ...
      source_location => '/software',
      ...
    }

[Back to overview of software](#attributes)


### version<a name='software_version'>

The version to be installed. Here is an example on how to use this:

    class { '::mq_install::software':
      ...
      version => '9.0.0.0',
      ...
    }

[Back to overview of software](#attributes)


### tmp_dir<a name='software_tmp_dir'>

This defined type uses a temporary directory. By default this is `\tmp`. If you want to use an other directory for this, you must specify this parameter.

Here is an example on how to use this:

    class { '::mq_install::software':
      ...
      tmp_dir => '/my_tmp_dir',
      ...
    }

On systems with a secured `/tmp` direcory, you MUST specify the `tmp_dir` parameter and specify a directory that puppet is allowed to execute scripts from. It must also have enough space to receive the extracted MQ installation kit.

[Back to overview of software](#attributes)


### install_ams<a name='software_install_ams'>

Specify a value of `true` when you want to install this component. Here is an example:

    class { '::mq_install::software':
      ...
      install_ams => true,
      ...
    }

The default is 'false'. Meaning this component is not installed.

[Back to overview of software](#attributes)


### install_ft<a name='software_install_ft'>

Specify a value of `true` when you want to install this component. Here is an example:

    class { '::mq_install::software':
      ...
      install_ft => true,
      ...
    }

The default is 'false'. Meaning this component is not installed.

[Back to overview of software](#attributes)


### install_client<a name='software_install_client'>

Specify a value of `true` when you want to install this component. Here is an example:

    class { '::mq_install::software':
      ...
      install_client => true,
      ...
    }

The default is 'false'. Meaning this component is not installed.

[Back to overview of software](#attributes)


### install_explorer<a name='software_install_explorer'>

Specify a value of `true` when you want to install this component. Here is an example:

    class { '::mq_install::software':
      ...
      install_explorer => true,
      ...
    }

The default is 'false'. Meaning this component is not installed.

[Back to overview of software](#attributes)


### install_xrserver<a name='software_install_xrserver'>

Specify a value of `true` when you want to install this component. Here is an example:

    class { '::mq_install::software':
      ...
      install_xserver => true,
      ...
    }

The default is 'false'. Meaning this component is not installed.

[Back to overview of software](#attributes)


### install_samples<a name='software_install_samples'>

Specify a value of `true` when you want to install this component. Here is an example:

    class { '::mq_install::software':
      ...
      install_samples => true,
      ...
    }

The default is 'false'. Meaning this component is not installed.

[Back to overview of software](#attributes)


### install_sdk<a name='software_install_sdk'>

Specify a value of `true` when you want to install this component. Here is an example:

    class { '::mq_install::software':
      ...
      install_sdk => true,
      ...
    }

The default is 'false'. Meaning this component is not installed.

[Back to overview of software](#attributes)


### install_man<a name='software_install_man'>

Specify a value of `true` when you want to install this component. Here is an example:

    class { '::mq_install::software':
      ...
      install_man => true,
      ...
    }

The default is 'false'. Meaning this component is not installed.

[Back to overview of software](#attributes)


### install_gskit<a name='software_install_gskit'>

Specify a value of `true` when you want to install this component. Here is an example:

    class { '::mq_install::software':
      ...
      install_gskit => true,
      ...
    }

The default is 'false'. Meaning this component is not installed.

[Back to overview of software](#attributes)


### install_amqp<a name='software_install_amqp'>

Specify a value of `true` when you want to install this component. Here is an example:

    class { '::mq_install::software':
      ...
      install_amqp => true,
      ...
    }

The default is 'false'. Meaning this component is not installed.

[Back to overview of software](#attributes)


### logoutput<a name='software_logoutput'>

If you want to see the output of the `exec` resources in the type, you can set this value to `true`. The default is `on_failure`.

Here is an example on how to use this:

    class { '::mq_install::software':
      ...
      logoutput => true,
      ...
    }

[Back to overview of software](#attributes)

