#
# See the file "LICENSE" for the full license governing this code.
#
#
# This defined type create's an startup unit or startuup script for starting the named
# queue manager. It also create's the service and enables it.
#
define mq_install::autostart(
  Enum['present', 'absent'] $ensure = 'present',
  String  $path                     = lookup('mq_install::autostart::path'),
  String  $service_name             = lookup('mq_install::autostart::service_name'),
  Integer $mq_version               = lookup('mq_install::autostart::mq_version'),
  String  $mq_user                  = lookup('mq_install::autostart::mq_user'),
  String  $mq_group                 = lookup('mq_install::autostart::mq_group'),
  Integer $nofile_limit             = lookup('mq_install::os::nofile'),
  Integer $nproc_limit              = lookup('mq_install::os::nproc'),
)
{
  mq_install { "mq_install::autostart::${title}": }
  if $::osfamily == 'windows' { fail 'This module does not support Windows'}
  if $::systemd == undef  { fail 'Module camptocamp-systemd required. Probably not installed'}

  case($ensure) {
    'absent':  {
      $service_ensure =  'stopped'
      $service_enable =  false
    }
    'present': {
      $service_ensure = 'running'
      $service_enable =  true
    }
    default: { fail('Invalid value for ensure found.')}
  }

  $queue_manager_name = $title

  if $::systemd {
    ::systemd::unit_file { "${service_name}.service":
      ensure  => $ensure,
      path    => $path,
      content => epp('mq_install/mq.service.epp', {
        'mq_version'   => $mq_version,
        'mq_user'      => $mq_user,
        'mq_group'     => $mq_group,
        'nofile_limit' => $nofile_limit,
        'nproc_limit'  => $nproc_limit,
        }),
      notify  => Service["${service_name}${queue_manager_name}"],
    }

    #
    # When mq_manager starts the Queue Manager, it does so outside of the systemd context. To make
    # sure we can start it with systemd, we first have to stop it and then start the service.
    #
    -> exec {"stop ${queue_manager_name} running outside systemd":
      command => "/opt/mqm/bin/endmqm -i ${queue_manager_name}",
      path    => '/bin',
      user    => $mq_user,
      group   => $mq_group,
      onlyif  => "ps -eaf | grep '[${queue_manager_name}] -u ${mq_user}'",
      unless  => "systemctl --state running | grep ${queue_manager_name}",
    }

    -> service {"${service_name}${queue_manager_name}":
      ensure => $service_ensure,
      enable => $service_enable,
    }
  } else {

    file { "${path}/mq":
      ensure => $ensure,
      source => 'puppet:///modules/mq_install/mq',
      mode   => '0755',
    }

    ~>service {$service_name:
      ensure => $service_ensure,
      enable => $service_enable,
    }
  }
}
