#
# See the file "LICENSE" for the full license governing this code.
#
#
# Apply all OS specific requirements for the installation of the MQ software
#
class mq_install::os(
  Integer $nofile,
  Integer $nproc,
  Integer $shmall,
  Integer $shmmax,
  Integer $shmmni,
  Integer $overcommit_memory,
  Integer $overcommit_ratio,
  Integer $threads_max,
  Integer $pid_max,
  Integer $file_max,
  String  $mqm_password      = 'mqm',
  Boolean $managehome        = true,
) inherits mq_install
{
  mq_install { 'mq_install::os': }

  group {'mqm':
    ensure => 'present',
  }

  user{ 'mqm':
    ensure     => 'present',
    password   => $mqm_password,
    home       => '/var/mqm',
    shell      => '/bin/bash',
    comment    => 'This user was created by Puppet',
    groups     => ['mqm'],
    managehome => $managehome,
  }

  limits::limits{'mqm/nofile': both => $nofile,}
  limits::limits{'mqm/nproc': both => $nproc,}

  class { 'limits':
    manage_limits_d_dir => false,
  }
  contain limits

  sysctl { 'kernel.shmall':         ensure => present, value  => $shmall,}
  sysctl { 'kernel.shmmax':         ensure => present, value  => $shmmax,}
  sysctl { 'kernel.shmmni':         ensure => present, value  => $shmmni,}
  sysctl { 'vm.overcommit_memory':  ensure => present, value  => $overcommit_memory,}
  sysctl { 'vm.overcommit_ratio':   ensure => present, value  => $overcommit_ratio,}
  sysctl { 'kernel.threads-max':    ensure => present, value  => $threads_max,}
  sysctl { 'kernel.pid_max':        ensure => present, value  => $pid_max,}
  sysctl { 'fs.file-max':           ensure => present, value  => $file_max,}

}
